Module error

Module error 

Error types returned by identifier construction.

Structs

UnknownVariant
Error returned by an enum’s from_wire strict parser when the input string does not correspond to any variant defined in this schema version.

Enums

IdentifierError
Errors that can occur when constructing or validating an identifier.
LengthExpectation
Expected input-length contract for an identifier type, in bytes.