Error types returned by identifier construction.
Structs
- Unknown
Variant - Error returned by an enum’s
from_wirestrict parser when the input string does not correspond to any variant defined in this schema version.
Enums
- Identifier
Error - Errors that can occur when constructing or validating an identifier.
- Length
Expectation - Expected input-length contract for an identifier type, in bytes.